==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeAssetLoadInfoResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeAssetLoadInfoResponse extends AbstractModel {

    /**
    * 系统负载
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("CpuLoad")
    @Expose
    private AssetLoadSummary CpuLoad;

    /**
    * 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("MemLoad")
    @Expose
    private AssetLoadSummary MemLoad;

    /**
    * 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("DiskLoad")
    @Expose
    private AssetLoadSummary DiskLoad;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 系统负载
注意：此字段可能返回 null，表示取不到有效值。 
     * @return CpuLoad 系统负载
注意：此字段可能返回 null，表示取不到有效值。
     */
    public AssetLoadSummary getCpuLoad() {
        return this.CpuLoad;
    }

    /**
     * Set 系统负载
注意：此字段可能返回 null，表示取不到有效值。
     * @param CpuLoad 系统负载
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setCpuLoad(AssetLoadSummary CpuLoad) {
        this.CpuLoad = CpuLoad;
    }

    /**
     * Get 内存使用率
注意：此字段可能返回 null，表示取不到有效值。 
     * @return MemLoad 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public AssetLoadSummary getMemLoad() {
        return this.MemLoad;
    }

    /**
     * Set 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
     * @param MemLoad 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setMemLoad(AssetLoadSummary MemLoad) {
        this.MemLoad = MemLoad;
    }

    /**
     * Get 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。 
     * @return DiskLoad 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public AssetLoadSummary getDiskLoad() {
        return this.DiskLoad;
    }

    /**
     * Set 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
     * @param DiskLoad 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setDiskLoad(AssetLoadSummary DiskLoad) {
        this.DiskLoad = DiskLoad;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeAssetLoadInfoResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeAssetLoadInfoResponse(DescribeAssetLoadInfoResponse source) {
        if (source.CpuLoad != null) {
            this.CpuLoad = new AssetLoadSummary(source.CpuLoad);
        }
        if (source.MemLoad != null) {
            this.MemLoad = new AssetLoadSummary(source.MemLoad);
        }
        if (source.DiskLoad != null) {
            this.DiskLoad = new AssetLoadSummary(source.DiskLoad);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "CpuLoad.", this.CpuLoad);
        this.setParamObj(map, prefix + "MemLoad.", this.MemLoad);
        this.setParamObj(map, prefix + "DiskLoad.", this.DiskLoad);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1130-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeAssetLoadInfoResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeAssetLoadInfoResponse extends AbstractModel {

    /**
    * 系统负载
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("CpuLoad")
    @Expose
    private AssetLoadSummary CpuLoad;

    /**
    * 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("MemLoad")
    @Expose
    private AssetLoadSummary MemLoad;

    /**
    * 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("DiskLoad")
    @Expose
    private AssetLoadSummary DiskLoad;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 系统负载
注意：此字段可能返回 null，表示取不到有效值。 
     * @return CpuLoad 系统负载
注意：此字段可能返回 null，表示取不到有效值。
     */
    public AssetLoadSummary getCpuLoad() {
        return this.CpuLoad;
    }

    /**
     * Set 系统负载
注意：此字段可能返回 null，表示取不到有效值。
     * @param CpuLoad 系统负载
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setCpuLoad(AssetLoadSummary CpuLoad) {
        this.CpuLoad = CpuLoad;
    }

    /**
     * Get 内存使用率
注意：此字段可能返回 null，表示取不到有效值。 
     * @return MemLoad 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public AssetLoadSummary getMemLoad() {
        return this.MemLoad;
    }

    /**
     * Set 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
     * @param MemLoad 内存使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setMemLoad(AssetLoadSummary MemLoad) {
        this.MemLoad = MemLoad;
    }

    /**
     * Get 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。 
     * @return DiskLoad 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public AssetLoadSummary getDiskLoad() {
        return this.DiskLoad;
    }

    /**
     * Set 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
     * @param DiskLoad 硬盘使用率
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setDiskLoad(AssetLoadSummary DiskLoad) {
        this.DiskLoad = DiskLoad;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeAssetLoadInfoResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeAssetLoadInfoResponse(DescribeAssetLoadInfoResponse source) {
        if (source.CpuLoad != null) {
            this.CpuLoad = new AssetLoadSummary(source.CpuLoad);
        }
        if (source.MemLoad != null) {
            this.MemLoad = new AssetLoadSummary(source.MemLoad);
        }
        if (source.DiskLoad != null) {
            this.DiskLoad = new AssetLoadSummary(source.DiskLoad);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "CpuLoad.", this.CpuLoad);
        this.setParamObj(map, prefix + "MemLoad.", this.MemLoad);
        this.setParamObj(map, prefix + "DiskLoad.", this.DiskLoad);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
